# Code Reference - Custom Information

## df_file_interchange.ci.base

The base class for custom info is defined here.

::: df_file_interchange.ci.base.FIBaseCustomInfo

## df_file_interchange.ci.structured

The "standard" class for custom info is defined here along with a standard context (mostly to given an example of the format).

::: df_file_interchange.ci.structured.FIStructuredCustomInfo

::: df_file_interchange.ci.structured.generate_default_context

## df_file_interchange.ci.examples

Example(s) of using structured custom info. These are mostly for testing purposes but can be instructive as examples.

::: df_file_interchange.ci.examples.generate_example_with_metainfo_1



